import request from '@/utils/request'

export function list(query = {}) {
  return request({
    url: '/apimngr/list',
    method: 'get',
    params: query
  })
}

// 接口类型列表
export function typeList(query = {}) {
  return request({
    url: '/apitype/list',
    method: 'get',
    params: query
  })
}

// 根据id获取接口信息
export function findbyid(id) {
  return request({
    url: '/apimngr/findbyid',
    method: 'get',
    params: { id }
  })
}

export function findRelationbyid(id) {
  return request({
    url: '/apimngr/findRelationbyid',
    method: 'get',
    params: { id }
  })
}

// 版本管理
export function versionList(apiId) {
  return request({
    url: '/apiversion/list',
    method: 'get',
    params: { apiId }
  })
}

// 接口收藏列表
export function collectList(data) {
  return request({
    url: '/apiCollect/list',
    method: 'post',
    data
  })
}

// 接口收藏插入
export function collectInsert(data) {
  return request({
    url: '/apiCollect/insert',
    method: 'post',
    data
  })
}

// 接口收藏删除
export function collectCancel(data) {
  return request({
    url: '/apiCollect/cancel',
    method: 'post',
    data
  })
}

// 申请新增接口
export function applyInsertApi(data) {
  return request({
    url: '/apimngr/applyInsertApi',
    method: 'post',
    data
  })
}

// 新增接口列表
export function applyList(data) {
  return request({
    url: '/apimngr/applyList',
    method: 'post',
    data
  })
}

// 新增接口审核列表
export function applyExamineList(data) {
  return request({
    url: '/apimngr/examineList',
    method: 'post',
    data
  })
}

// 新增接口审核
export function applyExamine(data) {
  return request({
    url: '/apimngr/examineApi',
    method: 'post',
    data
  })
}

// 我的应用列表
export function myAppList(data) {
  return request({
    url: '/app/list',
    method: 'get',
    params: data
  })
}

// 获取开发者列表 /api
export function userList(data) {
  return request({
    url: '/user/listdevelopers',
    method: 'get',
    params: data
  })
}

// 获取首页调用次数
export function numberCalls(data) {
  return request({
    url: '/homepage/overview',
    method: 'get',
    params: data
  })
}

// 获取调用接口排行榜
export function apiRank(data) {
  return request({
    url: '/homepage/topapis',
    method: 'get',
    params: data
  })
}

// 获取应用排行榜
export function appRank(data) {
  return request({
    url: '/homepage/topapps',
    method: 'get',
    params: data
  })
}

// 获取应用排行榜
export function appPutin(data) {
  return request({
    url: '/homepage/appByDate',
    method: 'get',
    params: data
  })
}

// 事实调用情况
export function callFact(data) {
  return request({
    url: '/homepage/realTimeCall',
    method: 'get',
    params: data
  })
}

// 调用量地域分布
export function spread(data) {
  return request({
    url: '/homepage/region',
    method: 'get',
    params: data
  })
}

// 申请授权
export function empower(data) {
  return request({
    url: '/role/applyForAuth',
    method: 'post',
    data
  })
}
